* Output options: all can be turned on/off by adding or removing the "NO":
  page number, date, centering, or page breaks, page length and width; 
	OPTIONS nonumber nodate nocenter formdlim='-' pagesize=MAX linesize=120;

****** Day 2 activity: Working with Variables;

* Multivariate example data: "fammult.sas7bdat" 
  moms and dads from 1000 families, 3 variables at 5 occasions;

*****************************************************************************************;
* Task 1: Create a SAS library for where the data file is.
  Import it into the work library, and create a "dataname" macro variable for the file.
*****************************************************************************************;

* Define SAS library and filepath placeholder;
%LET activ2 = F:\13_Psyc930SAS\Day2_Activity;
LIBNAME activ2 "&activ2.";

* Define macro variable for dataname;
%LET dataname=work.FamMult;

* Import SAS data file into work library;
DATA &dataname.; 
	SET activ2.FamMult;
RUN;

*****************************************************************************************;
* Task 2: Compute 5 new variables:
* Means and Standard Deviations for the 2 sets of
	"mmon13-mmon17" and "dmon13-dmon17" variables,
    making sure the families have at least 4 observations to do so.
	The function for Standard Deviation is STD. 
* A new categorical variable from "mworkmn" that distinguishes
    part-time work (0-30.00 hours) from full-time work (30.01-40+ hours).
	Add a value label to be used in the output via PROC FORMAT.
* Add variable labels to all new variables.
*****************************************************************************************;

DATA &dataname.; SET &dataname.;
	* Get means and SD for mmon and dmon, if at least 4 observations;
	IF N(OF mmon13-mmon17) GE 4 THEN DO; 
		mmonMean = MEAN(OF mmon13-mmon17); mmonSD = STD(OF mmon13-mmon17); END;
		ELSE DO; mmonMean = .; mmonSD = .; END;
	IF N(OF dmon13-dmon17) GE 4 THEN DO; 
		dmonMean = MEAN(OF dmon13-dmon17); dmonSD = STD(OF dmon13-dmon17); END;
		ELSE DO; dmonMean = .; dmonSD = .; END;
	LABEL 
		mmonMean= "mmonMean: Mean of MMon (if at least 4 waves)"
		dmonMean= "dmonMean: Mean of MMon (if at least 4 waves)"
		mmonSD=   "mmonSD: SD of MMon (if at least 4 waves)"
		dmonSd=   "dmonSD: SD of DMon (if at least 4 waves)";
	* Recoding into part-time or full-time work;
		 IF mworkmn=.     THEN DO; fulltime=.; END;
	ELSE IF mworkmn LE 30 THEN DO; fulltime=0; END;
	ELSE IF mworkmn GT 30 THEN DO; fulltime=1; END;
	LABEL fulltime= "fulltime: Works 30+ hours (0=no, 1=yes)";
RUN;

* Add a value label to be used in the output via PROC FORMAT;
PROC FORMAT LIBRARY=WORK;
	VALUE Fwork 0="Part-Time Work" 1="Full-Time Work";
RUN;


*****************************************************************************************;
* Task 3: Now that you have your new variables, creat output that describes them.
  Use titles for each piece of output, but clear them after each one is done.

* Use PROC FREQ to see how many part-time vs. full-time moms you have.
    Use a FORMAT statement to have your value labels show up on the output.
* Use PROC UNIVARIATE to view descriptives for the mean "mmon" variable you created  
	separately by part-time vs. full-time mom work type. Use a FORMAT statement.
	Request histogram and QQplots for the variable using normal and lognormal.
* Use PROC MEANS to view descriptives for the mean "dmon" variable you created  
	only for full-time mom work type.

* Sort the file by FamilyID again.
* Save the finished file as "FamMultDone.sas7bdat".
*****************************************************************************************;

* Use PROC FREQ to see how many part-time vs. full-time moms you have.
    Use a FORMAT statement to have your value labels show up on the output;
TITLE1 "Number of Part-Time and Full-Time Moms";
PROC FREQ DATA=&dataname.;
	TABLE fulltime;
	FORMAT fulltime Fwork.;
RUN; TITLE1;

* Use PROC UNIVARIATE to view descriptives for the mean "mmon" variable you created  
	separately by part-time vs. full-time mom work type. Add a title.
	Request histogram and QQplots for the variable using normal and lognormal;
TITLE1 "Mean Mom Monitoring Per Work Type";
PROC UNIVARIATE DATA=&dataname.;
	CLASS fulltime; 
	FORMAT fulltime Fwork.;
	VAR mmonMean;
	HISTOGRAM mmonMean / NORMAL LOGNORMAL; 		 	* Overlay these curves and run tests;
	  	INSET NORMAL LOGNORMAL / FORMAT=6.2 POS=NE;	* Put summary stats in a box in northeast corner of plot;
	QQPLOT mmonMean / NORMAL(MU=est SIGMA=est); * Quantile-Quantile Plot assuming normal;
	  	INSET NORMAL / FORMAT=6.2;		* Put summary stats in a box in the plot (default is northwest);
	QQPLOT mmonMean / LOGNORMAL(THRESHOLD=est SCALE=est SHAPE=est); * Quantile-Quantile Plot assuming lognormal;
		INSET  LOGNORMAL / FORMAT=6.2;	* Put summary stats in a box in the plot;
RUN; QUIT; * Need both RUN and QUIT; TITLE1;

* Use PROC MEANS to view descriptives for the mean "dmon" variable you created  
	only for full-time mom work type;
TITLE1 "Dad Monitoring Stats for Full-Time Moms";
PROC MEANS DATA=&dataname.;
	WHERE fulltime=1;
	VAR dmonMean;
RUN; TITLE1;

* Sort and save finished file;
PROC SORT DATA=&dataname.; 
	BY FamilyID; 
RUN;
DATA activ2.FamMultDone; 
	SET &dataname.;
RUN;

	



	

	   




